#
# spec file for package acpica
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           acpica
Url:            http://acpica.org
# How to fetch acpi-tools:
# git clone http://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux-2.6
# cd linux-2.6/tools/power/acpi
# mkdir -p include/acpi
# cp ../../../include/acpi/* include/acpi
# tar -cvjf acpi-tools-3.15 `find *`
Version:        20140214
Release:        5.5
%define acpi_tools_dir acpi-tools-3.14
%define src_dir acpica-unix2-%{version}
%define dmp_ver 20110323
Summary:        This is a set of tools to display and debug your BIOS ACPI tables
License:        GPL-2.0
Group:          Development/Tools/Debuggers
Source:         %{src_dir}.tar.bz2
Patch1:         acpica-no-compiletime.patch
Patch2:         wmidump_add_she_bang.patch
Source1:        ec_access.c
Source2:        acpi_genl.tar.bz2
Source3:        acpi_validate
Source4:        wmidump.tar.bz2
Source5:        %{acpi_tools_dir}.tar.bz2
Source6:        generate_acpi-tools_tarball.sh
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  %ix86 ia64 x86_64
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  glibc-devel
Provides:       iasl

%description
The included tools share the same code as it is used in the ACPI
implementation of the kernel. The code of the acpica project is exactly
the same as the ACPI parser and interpreter code of the kernel and the
code gets synced regularly from the acpica project into the kernel.
E.g. if you identify bugs in the kernel's ACPI implementation it might
be easier to debug them in userspace if possible. If the bug is part of
the acpica code, it has to be submitted to the acpica project to get
merged into the mainline kernel sources.

iasl compiles ASL (ACPI Source Language) into AML (ACPI Machine
Language). This AML is suitable for inclusion as a DSDT in system
firmware. It also can disassemble AML, for debugging purposes.



Authors:
--------
    "Moore, Robert" <robert.moore@intel.com>
    and other Intel people

%prep
%setup -n %{src_dir} -a 2 -a 4 -a 5
%patch1 -p1
%patch2 -p1

%build
cc %{SOURCE1} %{optflags} -o ec_access
make -C acpi_genl CFLAGS="%{optflags}"
make -C wmidump CFLAGS="%{optflags}"
make OPT_CFLAGS="%{optflags}" HOST="_LINUX"
make -C %{acpi_tools_dir} CFLAGS="-DDEFINE_ALTERNATE_TYPES -I include %{optflags}"

%install
install -Dm 755 %{SOURCE3} %{buildroot}/usr/bin/acpi_validate
install -Dm 755 ec_access %{buildroot}/usr/sbin/ec_access

install -Dm 755 wmidump/wmidump %{buildroot}/usr/bin/wmidump
install -Dm 755 wmidump/wmixtract.py %{buildroot}/usr/bin/wmixtract
install -Dm 644 wmidump/README %{buildroot}/%{_docdir}/%{name}/README_wmidump

install -Dm 755 acpi_genl/acpi_genl %{buildroot}/usr/sbin/acpi_genl
install -Dm 644 acpi_genl/README %{buildroot}/%{_docdir}/%{name}/README_acpi_genl

install -Dm 644 changes.txt %{buildroot}/%{_docdir}/%{name}/changes.txt
make install DESTDIR="%{buildroot}"
# Latest acpidump is coming from kernel and not from acpica sources now.
rm -rf "%{buildroot}"/usr/bin/acpidump
make -C %{acpi_tools_dir} install DESTDIR="%{buildroot}" mandir=/usr/share/man

%files
%defattr(-,root,root)
/usr/bin/iasl
/usr/bin/acpiexec
/usr/bin/acpixtract
/usr/bin/acpisrc
/usr/bin/wmidump
/usr/bin/wmixtract
/usr/sbin/acpidump
/usr/sbin/acpi_genl
/usr/sbin/ec_access
/usr/bin/acpibin
/usr/bin/acpihelp
/usr/bin/acpinames
/usr/bin/acpi_validate
/usr/bin/acpiexamples
%{_mandir}/man8/acpidump.8*

%doc %{_docdir}/%{name}

%changelog
* Fri Mar 28 2014 lchiquitto@suse.de
- Include generate_acpi-tools_tarball.sh in the package's source.
* Wed Mar 12 2014 trenn@suse.de
- Add acpi-tools tarball from kernel sources: tools/power/acpi
  Use latest acpidump from there instead of acpica included one.
  This fixes acpidump on latest kernels.
- Add script for easier retrieving of acpi-tools tarball from kernel sources.
* Tue Mar 11 2014 trenn@suse.de
- Update to version 20140214
- Replace $RPM_OPT_FLAGS with %%{optflags} as suggested by tcech@suse.cz
* Fri Mar  7 2014 ro@suse.de
- set HOST for make to not blindly set the hostname
  as compiler definition
* Wed Jan 15 2014 trenn@suse.de
- Update to version 20140114
  Drop acpica-add_missing_examples_makefile.patch
  - > already included mainlaine.
* Thu Dec 19 2013 trenn@suse.de
- Update to version 20131218
  Add acpica-add_missing_examples_makefile.patch: They forgot to add a file
  to the tarball. This patch adds it from git repo.
  Drop acpica-fix_dots_in_path_for_p_option.patch: This patch is included
  in the newly provided version tarball already.
* Fri Dec 13 2013 trenn@suse.de
- Update to version 20131115
- Explicitly add commit 04d10e3c1f41a776cbed96dce2326ee649b9a0f0 to fix
  bnc#855050:
  acpica-fix_dots_in_path_for_p_option.patch
* Fri Aug 23 2013 trenn@suse.de
- Update to version 20130823
- remove already integrated patch:
  dmar-buf10.patch
* Tue Jul  9 2013 trenn@suse.de
- Fix Source3 vs Source4 typo (acpi_validate was broken)
* Fri May 24 2013 trenn@suse.de
- Update to version 20130517
  - remove acpidump tarball, it is now included in acpica main project
* Fri May 17 2013 trenn@suse.de
- Update to version 20130418
  - remove already integreated patches:
    acpica_make_CFLAGS_overridable
    bob_noop.patch
  - Add fix for DMAR table parsing issue:
    https://bugs.acpica.org/show_bug.cgi?id=999
* Mon Jan 28 2013 trenn@suse.de
- Add wmidump/wmixtract tools for easy WMI (or other) GUID parsing
* Wed Jan 23 2013 trenn@suse.de
- Fix tiny bug in acpi_validate which wrongly adds the file which
  is to be compiled additionally to the external reference tables
  list
* Wed Jan 23 2013 trenn@suse.de
- Make use of -in (Ignore NoOp opcodes/operators)
  to avoid false positive errors during compliation/disassembling
* Tue Jan 15 2013 trenn@suse.de
- Update to version 20121018
  - > remove some patches that got integrated
  - > Add one patch (bob_noop.patch) which will get integrated
    mainline: Stop and bail out when max error (200) count is reached.
    Introduce -in compile/disassemble option.
* Wed Jan  9 2013 trenn@suse.de
- Add acpi_validate script for easy disassembling and re-compilation
  of local ACPI tables or of an already existing acpidump file
* Wed Nov  7 2012 trenn@suse.de
- Update to latest version 20121018.
  - > one patch got accepted mainline -> removed.
* Wed Sep 19 2012 trenn@suse.de
- Update to latest version 20120913
- Add acpi_genl from http://www.lesswatts.org/projects/acpi/utilities.php
  Can be used to check for ACPI events via netlink (since /proc/acpi/events is
  is deprecated)
- Adjust to new Makefile layout
* Sun May 20 2012 trenn@suse.de
- Update to latest version 20120518
* Tue Jan  3 2012 cfarrell@suse.com
- license update: GPL-2.0
  You added ec_access.c with a GPL-2.0 (only) license. Now the spec file
  has to be updated to reflect this
* Wed Dec 21 2011 aj@suse.de
- Clarify license, it's GPL-2.0+ (bnc#711299).
* Thu Nov 24 2011 trenn@suse.de
- ACPICA version 20111123 released with full ACPI 5.0 support
  Detailed changelog can be found here:
  http://acpica.org/download/changes.txt
* Wed Jun 29 2011 trenn@suse.de
- Fix build for 32 bit
* Mon Jun 27 2011 trenn@suse.de
- Update to version 20110623
- Fixed some "set but not used" errors and a link order issue
  and sent patches upstream.
- Set "-Wno-unused-result" for some compilations -> too many
  offenders to fix that all up.
* Mon Jun 20 2011 idonmez@novell.com
- Add acpica-unix-const.patch: fix const correctness issue in
  AslCompilererror, http://www.acpica.org/bugzilla/show_bug.cgi?id=923
* Wed Apr 27 2011 idoenmez@novell.com
- Add acpica-unix-20110316-gcc46.patch: fix compilation with gcc 4.6
* Sun Apr 17 2011 crrodriguez@opensuse.org
- Disable both build dates in this package and in
  the files it generates as it both trigger either unneeded
  republish of itself or other bigger packages like virtualbox
- Provides: iasl too.
* Wed Mar 30 2011 trenn@suse.de
- Exchange selfmade patch with mainline one to fix build
* Wed Mar 30 2011 trenn@suse.de
- Updated to acpica version 20110316
  Changes are listed in /usr/share/doc/packages/acpica/changes.txt
- Fixed dynamic acpi table extract via acpidump/acpixtract
  by reverting acpica commit baab09e6857a427944068c5e599ea2ffb84f765b
- Fixed compile issue and submitted it mainline
* Thu Feb 24 2011 trenn@novell.com
- Add possibility to see changes via new -s param: -r [ -s sleep ]
* Fri Jan 14 2011 trenn@novell.com
- Remove stale acpidump patches
* Fri Jan 14 2011 trenn@novell.com
- Get latest acpidump tool from Len's acpi pmtools:
  * Also dump dynamically loaded SSDTs
- Build against its own headers instead of acpica headers
  - > unfortunately acpidump is still not part of acpica and
  adjusting things ourselves is too much overhead.
* Thu Jan 13 2011 trenn@novell.com
- Update to version 20110112
  Changes are listed in /usr/share/doc/packages/acpica/changes.txt
* Tue Oct 26 2010 trenn@novell.com
- Update to version 20100806
- Added ec_access executable to be able to debug the Embedded
  Controller together with CONFIG_ACPI_EC_DEBUGFS kernel .config
  option
* Sat Aug  7 2010 trenn@novell.com
- Update to version 20100806
  For details, see the changes.txt file in the package
  changes.txt can now be found in
  /usr/share/doc/packages/acpica/changes.txt
* Sun Jul  4 2010 trenn@novell.com
- Update to version 20100702
  For details, see acpica-unix-20100702/changes.txt
* Thu Apr 29 2010 trenn@novell.com
- Update to version 20100428
* Mon Mar  8 2010 trenn@novell.com
- Avoid (when compiling AML):
  DSDT.dsl 10307:   Name (_ADR, Zero)
  Error    4080 -                ^ Invalid object type for reserved name,
    must be (Integer)
* Fri Mar  5 2010 trenn@novell.com
- Updated to version 20100304
  Some ACPI 4.0 enhancements and a lot bug fixes and other
  enhancements. See changes.txt in the sources for details
* Wed Oct 14 2009 trenn@suse.de
- Updated to version 20091013
  Includes a bug fix to correctly disassmeble Unisys ES7000 tables
* Wed Aug 26 2009 meissner@suse.de
- as-needed fix no longer necessary
* Fri Jul 31 2009 trenn@suse.de
- Update to acpica version 20090730
  The ACPI 4.0 implementation for ACPICA is complete with this release.
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Wed Apr  8 2009 trenn@suse.de
- Initial check-in: Version 20090320
